'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var Taro = require('@tarojs/taro');
var require$$3 = require('@tarojs/runtime');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var Taro__default = /*#__PURE__*/_interopDefaultLegacy(Taro);
var require$$3__default = /*#__PURE__*/_interopDefaultLegacy(require$$3);

var statistics = /*#__PURE__*/Object.freeze({
    __proto__: null,
    get initOptions () { return exports.initOptions; },
    get default () { return yryztrack; }
});

/**
 * 获取页面pageName
 * @returns 页面pageName
 */
const getPath = () => {
    var _a;
    const path = ((_a = Taro__default["default"].getCurrentInstance().router) === null || _a === void 0 ? void 0 : _a.path) || "";
    // 去掉开头的 /，比如将 '/auto/home/index' 改为 'auto/home/index'
    return path.match(/^\/*/) ? path.replace(/^\/*/, "") : path;
};
/**
 * 页面链路
 * @returns 页面链路  e.g. pages/indexindex-pages/list/index
 */
const getPaths = () => {
    let paths = Taro__default["default"].getCurrentPages();
    if (paths.length > 2) {
        paths.map(item => {
            return item.route;
        }).slice(0, paths.length - 2);
        return paths.join('-');
    }
    else {
        return paths.map(item => {
            return item.route;
        }).join('-');
    }
};
/**
 * 获取设备型号
 * @returns 设备型号 e.g. iPhoneX  华为MateX
 */
const getPhone = () => {
    return Taro__default["default"].getSystemInfoSync().model;
};
/**
 * 拼接对象为请求字符串
 * @param obj - 待拼接的对象
 * @returns - 拼接成的请求字符串
 */
const encodeSeachParams = (obj) => {
    var params = [];
    Object.keys(obj).forEach(function (key) {
        var value = obj[key];
        if (typeof value === 'undefined') {
            value = '';
        }
        // 对于需要编码的文本（比如说中文）我们要进行编码
        params.push([key, encodeURIComponent(value)].join('='));
    });
    return params.join('&');
};

var utils = /*#__PURE__*/Object.freeze({
    __proto__: null,
    getPath: getPath,
    getPaths: getPaths,
    getPhone: getPhone,
    encodeSeachParams: encodeSeachParams
});

/*
 * @Description:
 * @Version: 2.0
 * @Autor: zhanghang
 * @Email: suchiva@126.com
 * @Date: 2021-12-07 14:37:20
 * @LastEditors: zhanghang
 * @LastEditTime: 2021-12-08 15:34:06
 */
/**
 * 上报埋点信息
 * @param data  请求参数
 */
let clearFlag;
const autoPull = (startTime) => {
    let dataQueue = Taro__default["default"].getStorageSync("dataQueue") || [];
    const start = startTime;
    let end;
    clearFlag = setInterval(() => {
        end = new Date().getTime();
        if (end - start >= exports.initOptions.interval) {
            requestData(dataQueue);
        }
    }, 1000);
};
function guid() {
    let d = new Date().getTime();
    const uuid = "xxxxxxxxxxxx4xxxyxxxxxxxxxxxxxxx".replace(/[xy]/g, function (c) {
        var r = (d + Math.random() * 16) % 16 | 0;
        d = Math.floor(d / 16);
        return (c == "x" ? r : (r & 0x3) | 0x8).toString(16);
    });
    return uuid;
}
const sendData = async (data) => {
    const frequency = exports.initOptions.frequency;
    let dataQueue = Taro__default["default"].getStorageSync("dataQueue") || [];
    if (dataQueue && dataQueue.length >= frequency) {
        Taro__default["default"].setStorageSync("dataQueue", []);
        requestData(dataQueue);
    }
    else if (data.behavior === "init") {
        dataQueue = [];
        dataQueue.push(data);
        Taro__default["default"].setStorageSync("dataQueue", dataQueue);
        requestData(dataQueue);
    }
    else {
        dataQueue.push(data);
        Taro__default["default"].setStorageSync("dataQueue", dataQueue);
    }
};
const requestData = async (data) => {
    clearInterval(clearFlag);
    if (exports.initOptions.appKey == "") {
        throw new Error("请配置appKey");
    }
    let _data = {
        appKey: exports.initOptions.appKey,
        envVersion: exports.initOptions.envVersion,
        currentTime: new Date().valueOf(),
        phone: getPhone(),
        deviceId: guid(),
    };
    const LOGIN_INFO = Taro__default["default"].getStorageSync("LOGIN_INFO");
    _data.userId =
        exports.initOptions.userId ||
            (LOGIN_INFO ? JSON.parse(LOGIN_INFO).authInfo.userId : "");
    let networkType = await Taro__default["default"].getNetworkType().then((res) => res.networkType);
    _data.netType = networkType;
    let dataStr = "";
    if (data.length > 0) {
        data.map((v, index) => {
            const item = Object.assign({}, Object.assign({}, _data), Object.assign({}, v));
            let sign = "&";
            if (index === 0) {
                sign = "?";
            }
            dataStr += `${sign}d=` + JSON.stringify(item);
        });
    }
    else {
        // 处理init
        const item = Object.assign({}, Object.assign({}, _data), Object.assign({}, data));
        dataStr += `?d=` + JSON.stringify(item);
    }
    if (exports.initOptions.debug) ;
    Taro__default["default"].request({
        url: exports.initOptions.url + dataStr,
        method: "GET",
    })
        .then(() => {
        if (exports.initOptions.debug) {
            // console.log("上报成功, 结果为：", res.data);
            const startTime = new Date().getTime();
            autoPull(startTime);
        }
    })
        .catch(() => {
        if (exports.initOptions.debug) ;
    });
};

var request = /*#__PURE__*/Object.freeze({
    __proto__: null,
    sendData: sendData
});

var commonjsGlobal = typeof globalThis !== 'undefined' ? globalThis : typeof window !== 'undefined' ? window : typeof global !== 'undefined' ? global : typeof self !== 'undefined' ? self : {};

function getAugmentedNamespace(n) {
	if (n.__esModule) return n;
	var a = Object.defineProperty({}, '__esModule', {value: true});
	Object.keys(n).forEach(function (k) {
		var d = Object.getOwnPropertyDescriptor(n, k);
		Object.defineProperty(a, k, d.get ? d : {
			enumerable: true,
			get: function () {
				return n[k];
			}
		});
	});
	return a;
}

var myProxy = {exports: {}};

var require$$0 = /*@__PURE__*/getAugmentedNamespace(utils);

var require$$1 = /*@__PURE__*/getAugmentedNamespace(request);

var require$$2 = /*@__PURE__*/getAugmentedNamespace(statistics);

(function (module, exports) {
const { getPath, getPaths } = require$$0;
const { sendData } = require$$1;
const statistics = require$$2;
const { document } = require$$3__default["default"];
!(function(t, i) {
    (module.exports = i()) ;
})(commonjsGlobal, function() {
    let originApp = App;
    let originPage = Page,
        originComponent = Component;

    return (
        /**
         * 代理app公共方法，监听小程序onLaunch启动事件和小程序onHide关闭事件
         */
        (App = function(app) {
            let startTime = null;
            let duration = null;

            const onLaunch = app.onLaunch;
            const onShow = app.onShow;
            const onHide = app.onHide;

            app.onLaunch = function(...args) {
                onLaunch.call(this, ...args);
                startTime = new Date().valueOf();
                let _data = {
                    behavior: "event",
                    startTime: startTime.toString(),
                    duration: 0,
                    eventType: "auto",
                    actionType: "onLaunch",
                };
                sendData(_data);
            };

            app.onShow = function(...args) {
                onShow.call(this, ...args);
            };

            app.onHide = function(...args) {
                onHide.call(this, ...args);
                let hideTime = new Date().valueOf();
                duration = (hideTime - startTime) / 1000; //秒
                let _data = {
                    behavior: "event",
                    startTime: startTime.toString(),
                    duration,
                    eventType: "auto",
                    actionType: "onHide",
                    pathName: getPath(),
                };
                sendData(_data);
            };

            return originApp(app);
        }),
        (Page = function(page) {
            let startTime = null;
            let duration = null;

            let pullDownNum = 0; //当前页面下拉刷新次数
            let reachBottomNum = 0; //当前页面上拉加载更多次数

            const onUnload = page.onUnload;
            const onShow = page.onShow;
            const onLoad = page.onLoad;
            const onTabItemTap = page.onTabItemTap;
            const onPullDownRefresh = page.onPullDownRefresh;
            const onReachBottom = page.onReachBottom;
            page.onPageScroll;
            /**
             * 代理页面卸载生命周期
             * @param  {...any} args 页面onUnload参数
             */
            page.onUnload = function(...args) {
                onUnload.call(this, ...args);
                let hideTime = new Date().valueOf();
                duration = (hideTime - startTime) / 1000; //秒

                let _data = {
                    behavior: "event",
                    startTime: startTime.toString(),
                    duration,
                    eventType: "auto",
                    actionType: "page",
                    pageName: getPath(),
                    path: getPaths(),
                };
                sendData(_data);
            };

            /**
             * 代理页面即将显示生命周期，再这里记录进入页面开始时间
             * @param  {...any} args 页面onShow参数
             */
            page.onShow = function(...args) {
                onShow.call(this, ...args);
                startTime = new Date().valueOf();
                let _data = {
                    behavior: "event",
                    startTime: startTime.toString(),
                    duration: 0,
                    eventType: "auto",
                    actionType: "page",
                    path: getPaths(),
                    pageName: getPath(),
                    currentTime: new Date().valueOf().toString(),
                };
                sendData(_data);
            };

            /**
             * 代理页面渲染完成生命周期，这里可以拿到页面参数/路由参数，可以用做参数上报
             * @param  {...any} args 页面onLoad参数
             */
            page.onLoad = function(...args) {
                onLoad.call(this, ...args);
            };

            /**
             * 代理TabBarItem 点击事件
             * @param  {...any} args 页面onTabItemTap参数
             */
            page.onTabItemTap = function(...args) {
                let _data = {
                    behavior: "event",
                    eventType: "auto",
                    actionType: "click",
                    eventId: args[0].pagePath,
                    pageName: "",
                    path: getPaths(),
                    currentTime: new Date().valueOf().toString(),
                };
                sendData(_data);
                onTabItemTap.call(this, ...args);
            };

            const methodFn = page.eh;

            /**
             * 代理元素点击事件
             * @param  {...any} args 方法点击event参数
             */
            page.eh = function(...args) {
                const e = args && args[0];
                if (e && e.type === "tap") {
                    if (
                        e.target.id.substr(0, 3) != "_n_" ||
                        statistics.initOptions.ignoreEventId == ""
                    ) {
                        // console.log("元素点击标识符:", e.target.id);
                        if (e.currentTarget.id == e.target.id) {
                            //代表真正的点击view
                            let _data = {
                                behavior: "event",
                                eventType: "auto",
                                actionType: "click",
                                eventId: document
                                    .getElementById(e.target.id)
                                    .className.replace(/undefined/g, "")
                                    .trim()
                                    .replace(/( )/g, "_") || e.target.id,
                                path: getPaths(),
                                pageName: getPath(),
                            };
                            sendData(_data);
                        }
                    }
                }
                methodFn.call(this, ...args);
            };

            /**
             * 代理下拉刷新事件
             * @param  {...any} args 下拉刷新参数
             */
            page.onPullDownRefresh = function(...args) {
                onPullDownRefresh.call(this, ...args);
                let hideTime = new Date().valueOf();
                duration = (hideTime - startTime) / 1000; //秒
                pullDownNum += 1;
                let _data = {
                    behavior: "event",
                    eventType: "auto",
                    actionType: "PullDown",
                    num: pullDownNum,
                    duration,
                    path: getPaths(),
                    pageName: getPath(),
                };
                sendData(_data);
            };

            /**
             * 代理页面级别的上拉加载更多事件
             * @param  {...any} args 上拉加载参数
             */
            page.onReachBottom = function(...args) {
                onReachBottom.call(this, ...args);
                let hideTime = new Date().valueOf();
                duration = (hideTime - startTime) / 1000; //秒
                reachBottomNum += 1;
                let _data = {
                    behavior: "event",
                    eventType: "auto",
                    actionType: "onReachBottom",
                    num: reachBottomNum,
                    duration,
                    path: getPaths(),
                    pageName: getPath(),
                };
                sendData(_data);
            };

            return originPage(page);
        }),
        (Component = function(component) {
            return originComponent(component);
        })
    );
});
}(myProxy));

/*
 * @Description:
 * @Version: 2.0
 * @Autor: zhanghang
 * @Email: suchiva@126.com
 * @Date: 2021-12-07 14:37:20
 * @LastEditors: zhanghang
 * @LastEditTime: 2021-12-08 11:54:47
 */
const { document } = require("@tarojs/runtime");
exports.initOptions = void 0;
const yryztrack = {
    /**
     * 初始化自动上报
     * @param options 初始化参数
     */
    init(options) {
        exports.initOptions = {
            appKey: options.appKey,
            debug: options.debug || false,
            envVersion: options.envVersion || "dev",
            ignoreEventId: options.ignoreEventId || "",
            interval: options.interval || 10,
            frequency: options.frequency || 1000 * 60 * 5,
            url: options.url || "https://tj.yryz.com/log2.gif",
        };
        let _data = {
            behavior: "init",
            channel: "applet",
        };
        sendData(_data);
    },
    /**
     * 上报用户信息
     * @param userInfo 用户信息
     */
    setUserInfo(userInfo) {
        exports.initOptions.userId = userInfo.userId;
        let _data = Object.assign({ behavior: "userInfo" }, userInfo);
        sendData(_data);
    },
    /**
     * 页面自定义埋点
     * @param eventId 页面埋点事件唯一标识符
     * @param data 唯一标识符对应所需埋点内容
     */
    pageTrack(eventId, data) {
        let _data = {
            behavior: "event",
            eventType: "custom",
            actionType: "page",
            pageName: getPath(),
            path: getPaths(),
            eventId: document
                .getElementById(eventId)
                .className.replace(/undefined/g, "")
                .trim()
                .replace(/( )/g, "_") || eventId,
            duration: 0,
            data,
            currentTime: new Date().valueOf(),
        };
        sendData(_data);
    },
    /**
     * 元素自定义埋点点击事件
     * @param eventId 元素埋点事件唯一标识符
     * @param data 唯一标识符对应所需埋点内容
     */
    track(eventId, obj) {
        let _data = Object.assign({ behavior: "event", eventType: "custom", actionType: "click", path: getPaths(), pageName: getPath(), eventId: document
                .getElementById(eventId)
                .className.replace(/undefined/g, "")
                .trim()
                .replace(/( )/g, "_") || eventId, currentTime: new Date().valueOf() }, obj);
        sendData(_data);
    },
};

exports["default"] = yryztrack;
